cocos.audio.SDL.sound module — cocos v0.6.5 documentation

# cocos.audio.SDL.sound module

System Message: WARNING/2 (`F:\dev\cocos2017\docgen\api\cocos.audio.SDL.sound.txt`, line 4)

autodoc: failed to import module ‘cocos.audio.SDL.sound’; the following exception was raised: Traceback (most recent call last): File “F:\dev\cocos2017\cocos\audio\SDL\dll.py”, line 60, in __init__ self._load_library_win() File “F:\dev\cocos2017\cocos\audio\SDL\dll.py”, line 92, in _load_library_win self._dll = getattr(cdll, self.library_name) File “c:\python36\lib\ctypes\__init__.py”, line 418, in __getattr__ dll = self._dlltype(name) File “c:\python36\lib\ctypes\__init__.py”, line 348, in __init__ self._handle = _dlopen(self._name, mode) OSError: [WinError 126] No se puede encontrar el módulo especificado During handling of the above exception, another exception occurred: Traceback (most recent call last): File “c:\python36\lib\site-packages\sphinx\ext\autodoc.py”, line 657, in import_object __import__(self.modname) File “F:\dev\cocos2017\cocos\audio\SDL\sound.py”, line 47, in <module> _dll = SDL.dll.SDL_DLL(‘SDL_sound’, None, ‘1.2’) File “F:\dev\cocos2017\cocos\audio\SDL\dll.py”, line 63, in __init__ library_name)) ImportError: Dynamic library “SDL_sound” was not found